@@ -1,3 +1,8 @@
+//####  History
+//#---------------------------------------------------------------------
+//2016-02-14 Paco Bei Falscheingabe Kennwort wird nun ausgegeben, welche
+//                Zeichen verboten sind (checkPassword)
+
 // ueberprueft, ob mindestens 1 Zeichen fuer einen OP-Punkt angegeben worden sind
 function checkOPEntry (strTitle) {
     if (strTitle.length < jsMinOpentryLength) {
@@ -150,7 +155,7 @@ function checkPassword(strPwd, iLength){
   }
 
   if ((strPwd.indexOf("'") >= 0) || (strPwd.indexOf(" ") >= 0) || (strPwd.indexOf('"') >= 0)) {
-    alert("Ihre Benutzername bzw. Ihr Kennwort ist ungueltig!\nBitte waehlen geben Sie ein anderes ein.");
+    alert("Ihre Benutzername bzw. Ihr Kennwort ist ungueltig!\n\nKeine Hochkommas oder Leerzeichen erlaubt!!\n\nBitte geben Sie ein anderes ein.");
     return false;
   }
   return true;
